@@ -1,12 +1,13 @@
-import os
 import logging
+import os
 from pathlib import Path
 
 from django.conf import settings
+from django.core.management.base import BaseCommand
 from django.utils import timezone
 from django.utils.dateparse import parse_datetime
-from django.core.management.base import BaseCommand
 
+from django_backup_utils.apps import BackupUtilsConfig
 from django_backup_utils.helpers import get_backup_name, extract_dumpinfo, get_system_migrations, \
     get_backup_list_by_time
 
@@ -41,7 +42,7 @@ class Command(BaseCommand):
     def handle(self, hostname, projectname, all, showinfo, showlatest, *args, **options):
         if os.path.exists(settings.BACKUP_ROOT):
 
-            latest, sorted_backups = get_backup_list_by_time(settings.BACKUP_ROOT, hostname, projectname, all)
+            sorted_backups = get_backup_list_by_time(settings.BACKUP_ROOT, hostname, projectname, all)
 
             if not sorted_backups:
                 print("no backups found")
@@ -50,7 +51,7 @@ class Command(BaseCommand):
                     system_migrations_migrated, system_migrations_files = get_system_migrations()
 
                 if showlatest:
-                    print(latest)
+                    sorted_backups = [sorted_backups[-1]]
 
                 for index, backup in enumerate(sorted_backups):
                     prefix = f"{index + 1}\t  "
@@ -63,11 +64,14 @@ class Command(BaseCommand):
                         print(f"created at:\t\t\t{time.astimezone(tz=timezone.get_current_timezone())}")
                         print(
                             f"size:\t\t\t\t{round(float(Path(backup.get('path')).stat().st_size / 1000 / 1000), 4)} MB")
+                        print(f"backup directories: \t\t{info.get('backup_directories')}\n")
                         print(f"dump version:\t\t\t{info.get('dump_version')}")
                         print(f"dump migration files:\t\t{info.get('dump_migration_files')}")
+                        print(f"dump django-backup-utils:\t{info.get('django_backup_utils_version')}\n")
                         print(f"current system version:\t\t{settings.BACKUP_SYSTEM_VERSION}")
                         print(
-                            f"current migrations:\t\t{system_migrations_migrated} / files found: {system_migrations_files}")
+                            f"current migrations:\t\t{system_migrations_migrated} (applied) | {system_migrations_files} (files found)")
+                        print(f"current django-backup-utils:\t{BackupUtilsConfig.DJANGO_BACKUP_UTILS_VERSION}")
                         print("----------------------")
         else:
             print(f"no backups have been created yet")
