@@ -19,10 +19,15 @@ class Command(BaseCommand):
             if not sorted_backups:
                 print("no backups found")
             else:
-                synclist = synchronize_backups(sorted_backups)
-                for each in synclist:
+                synclist, dellist = synchronize_backups(sorted_backups)
+                for index, each in enumerate(synclist):
                     logger.debug(f"synchronized {each.__dict__}")
                     if not silent:
-                        print(f"synchronized {each.backup} -> {each}")
+                        print(f"{index+1}\tsynchronized {each.backup}\t\t({each})")#
+                print()
+                for index, each in enumerate(dellist):
+                    if not silent:
+                        print(f"{index+1}\tdeleted obj  {each.get('path')}\t\t({each.get('str')})")
+
         else:
             print(f"no backups have been created yet")
