@@ -35,7 +35,7 @@ def synchronize_backups_view(request):
 
         helpers.synchronize_backups(sorted_backups)
 
-        if len(sorted_backups) == 0:
+        if not sorted_backups:
             word = f"no backups"
         elif len(sorted_backups) == 1:
             word = f"{len(sorted_backups)} backup"
